# APPENDIX EXHIBITS: Figures and Tables
# 


source('code/load.R')


## Reweighting function
entropy_weighting = function(data) {
  fulldata = prepare_data() %>%
    select(gender, birth_year, hs_language_english, monthly_income_total, expectedincome_age40, realest_totalowned, plan_july1_2017_pos) %>%
    mutate(treat = 1)
  est = data %>% select(gender, birth_year, hs_language_english, monthly_income_total, expectedincome_age40, realest_totalowned, plan_july1_2017_pos) %>% 
    mutate(treat=0) %>% bind_rows(fulldata)
  w <- weightit(treat ~ ., data = est, estimand = "ATT", method = "entropy")
  weights = w$weights[1:nrow(data)]
  weights = weights/sum(weights)
  return(weights)
}



# Randomization inference function
get_randomized_inference_p_value = function(formula, assignment_var, data) {
  # Declaration clusters
  declaration <- with(data,{declare_ra(clusters = treatment_cell)})
  # Conduct Randomization Inference
  ri2_out <- conduct_ri(formula = formula,
                        assignment=assignment_var,
                        declaration = declaration,
                        sharp_hypothesis = 0,
                        data = data,
                        p='two-tailed')
  ri_p = tidy(ri2_out)$p.value %>% sprintf("%.3f", .)
  return(ri_p)
}





# =================================  FIGURES ==================================# 
# Figure D.2: minimal/takeup-proportions
make_participation_bar_graphs = function(data) {
  tl = 0.018
  data = data %>% mutate(treatment_type = ifelse(treatment_main == 1, 'Treatment', ifelse(treatment_subway == 1, 'Placebo', 'Pure control')))
  
  # Takeup proportions 
    data$q1_subway = na.fill(data$q1_subway, 0)
  data = data %>% mutate(complied = ( (treatment_type == 'Treatment' & participate_july1_2017>0) | (treatment_type == 'Placebo' & q1_subway==1))) %>%
    filter(treatment_type!='Pure control')
  
  
  # Calculate p-value
  formula = as.formula(str_interp('complied~treatment_type|treatment_cell|0|treatment_cell'))
  model = felm(formula, data=data, weights=data$weight)
  hyp = linearHypothesis(model, c("treatment_typeTreatment = 0"), test='F', singular.ok = TRUE)
  p = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
  

  takeup = data %>% group_by(treatment_type) %>% 
    summarise(mean = weighted.mean(complied, w=weight), se = weighted.sd(complied, w=weight)/sqrt(n())) %>%
    mutate(high = mean+1.96*se, low = mean-1.96*se)
  
  ggplot(takeup, aes(x = treatment_type, y = mean)) + 
    geom_bar(stat='identity', alpha=0.8, width = 0.5, aes(fill = treatment_type)) +
    geom_errorbar(aes(ymin = low, ymax = high), width=0.2, alpha=0.5) +
    ylab('Takeup proportion') + xlab('Treatment group') +
    guides(fill=F) +
    geom_signif(annotation = p, xmin = 1, xmax=2, y_position = 0.21, tip_length = tl, textsize=7) +
    theme_two_placebo_treatment
    
  ggsave(str_interp('${out}/takeup-proportions.pdf'))
  
}


# Figure D.3
make_interactions_linear = function(data, measure) {


  paren = ifelse(title_weight_tag==' (reweighted sample)', str_interp('(${measure} intensity, reweighted sample)'),
                 str_interp('(${measure} intensity${title_weight_tag})'))
 
  
  data =data %>% 
    select(participate_july1_2017, participate_july1_2018, treatment_main, treatment_cell, treatment_cell_tier, approximate_treatment_cell_tier, weight) %>% 
    gather(year, value, -c(treatment_main, treatment_cell_tier, approximate_treatment_cell_tier, treatment_cell, weight)) %>%
    mutate(treatment_main = factor(ifelse(treatment_main==1, 'Treatment', 'Control'), levels= c('Control','Treatment')), 
           year = substring(year, nchar(year)-3, nchar(year)))
  binmeans = data %>% group_by(approximate_treatment_cell_tier, treatment_cell_tier, treatment_cell, year, treatment_main) %>% 
    summarise(mean_participation = weighted.mean(value, weight), n = n()) %>%
    mutate(size = cut(n, c(0, 2, 5, 10, 15, 30, 52), labels = c('1-2','3-5','6-10','11-15','16-30', '31-51')))
  intensity = ifelse(measure=='target','approximate_treatment_cell_tier','treatment_cell_tier')
  
  p = ggplot(data, aes_string(x = intensity, y = 'value', col = 'treatment_main', fill='treatment_main')) + 
    xlab('Share treated in cell') + ylab('Proportion participating') +
    labs(linetype = 'Year', color = 'Treatment group', shape='Treatment group', size = 'Group size') + 
    scale_x_continuous(breaks = c(0, .25, .50, .75, 1), limits=c(0, 1)) +
    scale_size_manual(values=c(1, 2, 3.5, 5, 6.5, 10)) +
    guides(fill = F, color = guide_legend(override.aes = list(linetype = 0, size=3))) +
    facet_wrap(~year) +
    geom_point(data=binmeans, aes_string(x = intensity, y = 'mean_participation', size='size', shape='treatment_main', col='treatment_main'), alpha=0.6) +
    theme(axis.text=element_text(size=rel(1.2), color='black'), axis.title = element_text(size=rel(1.3)), panel.spacing = grid::unit(1, 'cm'),
          strip.text = element_text(size=rel(1.2)), legend.text=element_text(size=rel(1.15)), legend.title = element_text(size=rel(1.15)))
    # If background should be white: + theme_bw() + theme(strip.background=element_rect(fill="white"))
  
  grouped = data %>% group_by(treatment_main, year) %>%
    nest() %>%
    mutate(model = map(data, function(df) tidy(lm(as.formula(str_interp('value~${intensity}')), data=df))),
           intercept = as.numeric(map(model, function(x) unlist(x[1, 2]))), 
           coef = as.numeric(map(model, function(x) unlist(x[2, 2]))), 
           pval = map_chr(model, function(x) as.numeric(unlist(x[2, 5])) %>% round(3) %>% sprintf("%.3f", .))) %>%
    select(-model, -data) %>%
    mutate(yloc  = ifelse(treatment_main=='Control', 0.77, 0.85), 
           pval = paste0('p=', pval))
  p = p + geom_abline(data=grouped, aes(slope=coef, intercept=intercept, col=treatment_main))

  ggsave(str_interp('${out}/social-utility-${label_weight_tag}-${measure}.pdf'), p, width = 8, height = 5)
  
}





# =================================  TABLES ==================================#

create_row = function(outcome, data, name=NA, type) {
  data = data %>% mutate(complier = treatment_main == 1 & participate_july1_2017 == 1)
  term = 'complier'
  if (type == 'control') {
    data = data %>% filter(participate_july1_2017 == 1)
    formula = as.formula(str_interp('${outcome} ~ complier|0|0|0'))
  } else if (type == 'any_past_protests-tr') {
    data = data %>% filter(past_protests | complier)
    data$past_protests[data$past_protests & data$complier] = F

    formula = as.formula(str_interp('${outcome} ~ complier|0|0|0'))
  } else if (type == 'attrition') {
    term = 'fullsample'
    formula = as.formula(str_interp('${outcome} ~ fullsample|0|0|0'))
  }
  if (outcome == 'obs') {
    control_obs = sum(data[,term]==0)
    treatment_obs = sum(data[,term]==1)
    overall_obs = nrow(data)
    return(c(overall_obs, control_obs, treatment_obs))
  }
  if (outcome == 'obs3') {
    main_obs = sum(data$treatment_main)
    subway_obs = sum(data$treatment_subway)
    control_obs = nrow(data) - main_obs - subway_obs
    return(c(nrow(data), control_obs, subway_obs, control_obs+subway_obs, main_obs))
  }
  if (name == 'HH monthly income') {
    n = 0
  } else if (name == 'Birth year' | name == 'Expected income at age 40'){
    n = 2
  } else {
    n = 3
  }
  flag = str_interp("%.${n}f")
  overall_mean = weighted.mean(data[,outcome] %>% unlist() %>% as.numeric(),  w = data$weight)  %>% round(n) %>% sprintf(flag, .)
  overall_sd = weighted.sd(data[,outcome]  %>% unlist() %>% as.numeric(),  w = data$weight) %>% round(n)%>% sprintf(flag, .)
  if (type!='balance3') {
    control_mean = weighted.mean(data[data[,term]==0,outcome] %>% unlist() %>% as.numeric, w = data$weight[data[,term]==0]) %>% round(n) %>% sprintf(flag, .)
    treatment_mean = weighted.mean(data[data[,term]==1,outcome] %>% unlist() %>% as.numeric,w = data$weight[data[,term]==1]) %>% round(n) %>% sprintf(flag, .)
    model = felm(formula, weights = data$weight, data=data)
    df = tidy(model)
    p = df[df$term==ifelse(term=='complier', 'complierTRUE', term),'p.value'] %>% round(3) %>% sprintf("%.3f", .)
    return(paste(c(name, overall_mean, overall_sd, control_mean, treatment_mean, p), collapse = ' & '))
  } else {
    control_mean = weighted.mean(data[data$treatment_main==0 & data$treatment_subway == 0,outcome] %>% unlist %>% as.numeric, w = data$weight[data$treatment_main==0 & data$treatment_subway == 0]) %>% round(n) %>% sprintf(flag, .)
    subway_mean = weighted.mean(data[data$treatment_subway == 1,outcome] %>% unlist %>% as.numeric,  w = data$weight[data$treatment_subway == 1]) %>% round(n) %>% sprintf(flag, .)
    treatment_mean = weighted.mean(data[data$treatment_main == 1,outcome] %>% unlist %>% as.numeric, w = data$weight[data$treatment_main == 1]) %>% round(n) %>% sprintf(flag, .)
    pooled_mean = weighted.mean(data[data$treatment_main != 1,outcome] %>% unlist %>% as.numeric, w = data$weight[data$treatment_main != 1]) %>% round(n) %>% sprintf(flag, .)
    
    # Control vs subway
    model = felm(as.formula(str_interp('${outcome} ~ treatment_subway|0|0|treatment_cell')), data=data %>% filter(treatment_main==0), weights=data$weight[data$treatment_main==0])
    df = tidy(model)
    pcs = df[df$term=='treatment_subway','p.value'] %>% round(3) %>% sprintf("%.3f", .)
    # Control vs treatment
    model = felm(as.formula(str_interp('${outcome} ~ treatment_main|0|0|treatment_cell')), data=data %>% filter(treatment_subway==0), weights=data$weight[data$treatment_subway==0])
    df = tidy(model)
    pct = df[df$term=='treatment_main','p.value'] %>% round(3) %>% sprintf("%.3f", .)
    # Subway vs treatment
    model = felm(as.formula(str_interp('${outcome} ~ treatment_main|0|0|treatment_cell')), data=data %>% filter(treatment_main==1 | treatment_subway==1), weights=data$weight[data$treatment_main==1 | data$treatment_subway==1])
    df = tidy(model)
    pst = df[df$term=='treatment_main','p.value'] %>% round(3) %>% sprintf("%.3f", .)
    # Treatment vs pooled control
    model = felm(as.formula(str_interp('${outcome} ~ treatment_main|0|0|treatment_cell')), data=data, weights=data$weight)
    df = tidy(model)
    ppt = df[df$term=='treatment_main','p.value'] %>% round(3) %>% sprintf("%.3f", .)
    return(paste(c(name, overall_mean, overall_sd, control_mean, subway_mean, pooled_mean, treatment_mean, pcs, pct, pst, ppt), collapse = ' & '))
  }
}



# Table D.1, D.2, D.5
make_balance = function(data, type) {
  rows = list()
  if (type == 'attrition') {
    flag = 'attrition'
    note = "\\textit{Notes:} Table presents mean individual characteristics for the entire sample recruited in 2017. It presents mean individual characteristics first for the sample that completed only Wave 1, then for the sample that completed all waves. It then tests for equality of means between the latter two groups. `English language high school' is an indicator of whether the subject completed high school with English as the formal language of instruction (as opposed to Chinese). `HH monthly income' is the self-reported total income earned by both parents (including sources of income such as dividends and rents). `Expected income at age 40' is a survey response indicating self-reported expectations of relative income compared to classmates at HKUST at age 40. `\\# real estate owned' is a measure of wealth: the number of real estate properties owned by a subject's parents/household in Hong Kong at the time of the survey. `Planned to participate in 2017 protest' is a subject's self-reported plan (as of June 2017) to participate in the July 1, 2017 march prior to the treatment assignment."
    group1 = 'Only wave 1'
    group2 = 'All waves'
    caption = 'Attrition across survey parts'
    data = data %>% mutate(fullsample = 1) 
    fulldata = prepare_data() %>%
      filter(is.na(az_polbeliefs_post18) | is.na(az_polbeliefs_pre18) | is.na(plan_july1_2018_positive)) %>%
      mutate(fullsample = 0)
    data = data %>% bind_rows(fulldata)
  }
  rows[[1]] = create_row('gender', data, 'Male', type)
  rows[[2]] = create_row('birth_year', data, 'Birth year', type)
  rows[[3]] = create_row('hs_language_english', data, 'English language high school', type)
  rows[[4]] = create_row('monthly_income_total', data, 'HH monthly income', type)
  rows[[5]] = create_row('expectedincome_age40', data, 'Expected income at age 40', type)
  rows[[6]] = create_row('realest_totalowned', data, '\\# real estate owned', type)
  rows[[7]] = create_row('plan_july1_2017_pos', data, 'Planned to participate in 2017 protest', type)
  rows[[8]] = create_row('past_protests', data, 'Participated in any previous protest', type)
  
  rows = unlist(rows)
  rows = paste0(rows, '\\\\')
  for (n in c(3,6,8)) {
    rows[n] = paste0(rows[n], '[5pt]')
  }
  if (type == 'control') {
    flag = 'balance-participants-2017treatment-vs-2017control'
    note = '\\textit{Notes:} Sample limited to protest participants. Control refers to the group that did not receive the main treatment, thus including individuals in the subway treatment group as well as the pure control group.'
    caption = 'Summary statistics and balance check: treatment vs. control (participants only)'
    group1 = 'Control'
    group2 = 'Treatment'
  } else if (type == 'any_past_protests-tr') {
    flag = 'balance-participants-2017-vs-any-past-tr'
    note = "\\textit{Notes:} Table studies the characteristics of protesters in the treatment group (taking them as suggestive of the ``compliers'' in the study, though they also include the ``always takers''), comparing these subjects to other experimental subjects who reported attending past protests. The table first presents mean individual characteristics for experimental subjects who either reported previously attending a protest, or who were treatment group protesters in 2017, or both. The table then splits this group, presenting mean individual characteristics for two disjoint sets: (i) experimental subjects who participated in past protests but were \\emph{not} treatment group protesters; and (ii) experimental subjects who were treatment group protesters. It then tests for equality of means between groups. `English language high school' is an indicator of whether the subject completed high school with English as the formal language of instruction (as opposed to Chinese). `HH monthly income' is the self-reported total income earned by both parents (including sources of income such as dividends and rents). `Expected income at age 40' is a survey response indicating self-reported expectations of relative income compared to classmates at HKUST at age 40. `\\# real estate owned' is a measure of wealth: the number of real estate properties owned by a subject's parents/household in Hong Kong at the time of the survey. `Planned to participate in 2017 protest' is a subject's self-reported plan (as of June 2017) to participate in the July 1, 2017 march prior to the treatment assignment."
    caption = "Evidence on compliers: comparing treatment group protesters to past protesters"
    group1 = 'Past'
    group2 = 'Treated'
  } else if (type == 'balance3') {
    flag = 'balance-all3'
    note = "\\textit{Notes:} Table presents mean individual characteristics for the entire experimental sample, then presents means for the pure control group, the placebo treatment group, the union of pure control and placebo treatment groups (`control'), and the treatment group, respectively. It then tests for pairwise equality of means between groups. `English language high school' is an indicator of whether the subject completed high school with English as the formal language of instruction (as opposed to Chinese). `HH monthly income' is the self-reported total income earned by both parents (including sources of income such as dividends and rents). `Expected income at age 40' is a survey response indicating self-reported expectations of relative income compared to classmates at HKUST at age 40. `\\# real estate owned' is a measure of wealth: the number of real estate properties owned by a subject's parents/household in Hong Kong at the time of the survey. `Planned to participate in 2017 protest' is a subject's self-reported plan (as of June 2017) to participate in the July 1, 2017 march prior to the treatment assignment. `Participated in any previous protest' is a self-reported indicator for having participated in a protest prior to 2017."
    caption = 'Summary statistics and balance check: main treatment vs. placebo vs. pure control'
  }
  if (type!='balance3') {
    template = readLines(str_interp('templates/table_template.tex'))
    obs = create_row(outcome='obs', data=data, type=type)  
    template[4] = str_interp('\\caption{${caption}}')
    template[5] = str_interp('\\label{t:${flag}}')
    template[12] = str_interp(' & \\multicolumn{2}{c}{${ifelse(type=="attrition", "Completed Wave 1", "Overall")}} & ${group1} & ${group2} &  \\\\')
    template[19] = str_interp("\\# of obs. & \\multicolumn{2}{c}{${obs[1]}} & ${obs[2]} & ${obs[3]} & - \\\\")
  } else {
    template = readLines(str_interp('templates/table_template3.tex'))
    obs = create_row(outcome='obs3', data=data, type=type)  
    template[19] = str_interp("\\# of obs. & \\multicolumn{2}{c}{${obs[1]}} & ${obs[2]} & ${obs[3]} & ${obs[4]} & ${obs[5]} & - & - & - & - \\\\")
  }
  template[which(str_detect(template, 'tableboxwidth'))] = str_interp("\\item {${note}}")
  rows = c(template[1:16], rows, template[17:length(template)])
  writeLines(rows, con = str_interp('${out}/${flag}.tex'))
}






# Table D.6
make_cell_balance = function(data) {
  intensity = data %>% group_by(approximate_treatment_cell_tier) %>% 
    summarise(gender = weighted.mean(gender, w=weight) %>% round(3) %>% sprintf('%.3f', .),
              birth_year = weighted.mean(birth_year, w=weight) %>% round(2) %>% sprintf('%.2f', .),
              hs_language_english = weighted.mean(hs_language_english, w=weight) %>% round(3) %>% sprintf('%.3f', .),
              monthly_income_total = weighted.mean(monthly_income_total, w=weight) %>% round(0),
              expectedincome_age40 = weighted.mean(expectedincome_age40,  w=weight) %>% round(3) %>% sprintf('%.3f', .),
              realest_totalowned = weighted.mean(realest_totalowned, w=weight) %>% round(3) %>% sprintf('%.3f', .),
              plan_july1_2017_pos = weighted.mean(plan_july1_2017_pos,  w=weight) %>% round(3) %>% sprintf('%.3f', .),
              past_protests = weighted.mean(past_protests, w=weight) %>% round(3) %>% sprintf('%.3f', .)) %>%
    t() %>%
    as.data.frame()
  names(intensity) = c('0-intensity', '1-intensity', '50-intensity', '75-intensity')
  intensity = intensity[-1,]
  intensity$variable = rownames(intensity)
  rownames(intensity) = 1:nrow(intensity)
  intensity = intensity[,c('variable', '0-intensity', '1-intensity', '50-intensity', '75-intensity')]
  intensity2 = data %>%
    summarise(gender = weighted.mean(gender,w=weight) %>% round(3) %>% sprintf('%.3f', .),
              birth_year = weighted.mean(birth_year,  w=weight) %>% round(2) %>% sprintf('%.2f', .),
              hs_language_english = weighted.mean(hs_language_english,  w=weight) %>% round(3) %>% sprintf('%.3f', .),
              monthly_income_total = weighted.mean(monthly_income_total,  w=weight) %>% round(0),
              expectedincome_age40 = weighted.mean(expectedincome_age40,  w=weight) %>% round(3) %>% sprintf('%.3f', .),
              realest_totalowned = weighted.mean(realest_totalowned,  w=weight) %>% round(3) %>% sprintf('%.3f', .),
              plan_july1_2017_pos = weighted.mean(plan_july1_2017_pos,  w=weight) %>% round(3) %>% sprintf('%.3f', .),
              past_protests = weighted.mean(past_protests, wt = weight) %>% round(3) %>% sprintf('%.3f', .)) %>%
    t() %>%
    as.data.frame()
  names(intensity2) = c('Overall')
  intensity2$variable = rownames(intensity2)
  rownames(intensity2) = 1:nrow(intensity2)
  intensity2 = intensity2[,c('variable','Overall')]
  intensity3 = data %>%
    summarise(gender = weighted.sd(gender, wt=weight) %>% round(3) %>% sprintf('%.3f', .),
              birth_year = weighted.sd(birth_year, wt=weight) %>% round(2) %>% sprintf('%.2f', .),
              hs_language_english = weighted.sd(hs_language_english, wt=weight) %>% round(3) %>% sprintf('%.3f', .),
              monthly_income_total = weighted.sd(monthly_income_total, wt=weight) %>% round(0),
              expectedincome_age40 = weighted.sd(expectedincome_age40, wt=weight) %>% round(3) %>% sprintf('%.3f', .),
              realest_totalowned = weighted.sd(realest_totalowned, wt=weight) %>% round(3) %>% sprintf('%.3f', .),
              plan_july1_2017_pos = weighted.sd(plan_july1_2017_pos, wt=weight) %>% round(3) %>% sprintf('%.3f', .),
              past_protests = weighted.sd(past_protests, wt=weight) %>% round(3) %>% sprintf('%.3f', .)) %>%
    t() %>%
    as.data.frame()
  names(intensity3) = c('SD')
  intensity3$variable = rownames(intensity3)
  rownames(intensity3) = 1:nrow(intensity3)
  intensity3 = intensity3[,c('variable','SD')]
  data$treatment_cell_tier = as.factor(data$treatment_cell_tier)
  p_values = data %>% select(treatment_cell_tier, gender, birth_year, hs_language_english, monthly_income_total, expectedincome_age40, realest_totalowned, plan_july1_2017_pos, past_protests) %>%
    gather(variable, value, -treatment_cell_tier) %>% 
    group_by(variable) %>%
    do(tidy(aov(value ~ treatment_cell_tier, data = .))) %>%
    filter(term == 'treatment_cell_tier') %>%
    select(variable, p.value) %>%
    mutate(p.value = sprintf('%.3f', round(p.value, 3)))
  intensity = intensity2 %>% inner_join(intensity3, by='variable') %>% inner_join(intensity,by='variable') %>% inner_join(p_values, by = 'variable')
  intensity$variable = c('Male','Birth year','English language high school','HH monthly income','Expected income at age 40',' # real estate owned', 'Planned to participate in 2017 protest', 'Participated in any previous protest')
  names(intensity)[1] = 'Variable'
  names(intensity)[length(intensity)] = 'p-value (ANOVA)'
  lines = xtable(intensity)  %>% capture.output() %>% .[9:15]
  lines = str_split_fixed(lines, '& ', 2)[,2]
  template = readLines('templates/table_template_cell_balance.tex')
  note = "Table presents mean individual characteristics at the cell level for the entire experimental sample, then presents mean cell characteristics across categories of cell treatment intensity: 0\\% treated, 1 individual treated, 50\\% treated, and 75\\% treated, respectively. It then tests for equality of means across all groups. `English language high school' is an indicator of whether the subject completed high school with English as the formal language of instruction (as opposed to Chinese). `HH monthly income' is the self-reported total income earned by both parents (including sources of income such as dividends and rents). `Expected income at age 40' is a survey response indicating self-reported expectations of relative income compared to classmates at HKUST at age 40. `\\# real estate owned' is a measure of wealth: the number of real estate properties owned by a subject's parents/household in Hong Kong at the time of the survey. `Planned to participate in 2017 protest' is a subject's self-reported plan (as of June 2017) to participate in the July 1, 2017 march prior to the treatment assignment. `Participated in any previous protest' is a self-reported indicator for having participated in a protest prior to 2017."
  lines = c(template[1:15], lines, template[17:20], str_interp('\\item \\textit{Notes: } ${note}'), template[22])
  lines[17] = paste0(lines[17], '[5pt]')
  lines[19] = paste0(lines[19], '[5pt]')
  lines[21] = paste0(lines[21], '[5pt]')
  n = (data %>% group_by(approximate_treatment_cell_tier) %>% summarise(n = length(unique(treatment_cell))))$n
  obs = str_interp('\\# of obs & \\multicolumn{2}{c}{${sum(n)}} & ${n[1]} & ${n[2]} & ${n[3]} & ${n[4]} & - \\\\')
  lines = c(lines[1:22], '\\midrule', obs,  lines[23:length(lines)])
  writeLines(lines, con = str_interp('${out}/cell-balance.tex'))
}




# Table D:9: this is a separate R script (individual-outcomes-table.R)


# Table D.11 (Table 1 reweighted)
make_participation_table = function(data, measure) {
  # Panel A: Average treatment effect
  formula1 = as.formula(str_interp('participate_july1_2017~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model1 = felm(formula1, data=data, weights=data$weight)
  formula2 = as.formula(str_interp('participate_july1_2017~treatment_main+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model2 = felm(formula2, data=data, weights=data$weight)
  formula3 = as.formula(str_interp('participate_july1_2018~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model3 = felm(formula3, data=data, weights=data$weight)
  formula4 = as.formula(str_interp('participate_july1_2018~treatment_main+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model4 = felm(formula4, data=data, weights=data$weight)
  
  formula5 = as.formula(str_interp('plan_july1_2017_pos~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model5 = felm(formula5, data=data, weights=data$weight)
  formula6 = as.formula(str_interp('plan_july1_2017_pos~treatment_main+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model6 = felm(formula6, data=data, weights=data$weight)
  formula7 = as.formula(str_interp('plan_july1_2018_positive~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model7 = felm(formula7, data=data, weights=data$weight)
  formula8 = as.formula(str_interp('plan_july1_2018_positive~treatment_main+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model8 = felm(formula8, data=data, weights=data$weight)
  
  
  empty_model = model1
  empty_model$beta[1:2] = c(NA, NA)
  empty_model$cse[1:2] = c(NA, NA)
  empty_model$N = c(NA)
  
  output_average = stargazer(list(model1, model2, model3, model4, empty_model, model7, model8),   # model6, model7 not shown
                             omit = c('gender','predicted'),
                             covariate.labels = c('Treatment'),
                             title = 'Treatment effects: protest participation and plans (reweighted sample)',
                             label = str_interp('t:participation-${measure}'),
                             star.char = '')
  
  # Panel B: Heterogeneity
  data$approximate_treatment_cell_tier = relevel(data$approximate_treatment_cell_tier, ref=2)
  var = ifelse(measure=='empirical', 'treatment_cell_tier', 'approximate_treatment_cell_tier')
  formula1 = as.formula(str_interp('participate_july1_2017~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model1 = felm(formula1, data=data, weights=data$weight)
  formula2 = as.formula(str_interp('participate_july1_2017~treatment_main+treatment_main:${var}+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model2 = felm(formula2, data=data, weights=data$weight)
  formula3 = as.formula(str_interp('participate_july1_2018~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model3 = felm(formula3, data=data, weights=data$weight)
  formula4 = as.formula(str_interp('participate_july1_2018~treatment_main+treatment_main:${var}+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model4 = felm(formula4, data=data, weights=data$weight)
  
  formula5 = as.formula(str_interp('plan_july1_2017_pos~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model5 = felm(formula5, data=data, weights=data$weight)
  formula6 = as.formula(str_interp('plan_july1_2017_pos~treatment_main+treatment_main:${var}+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model6 = felm(formula6, data=data, weights=data$weight)
  formula7 = as.formula(str_interp('plan_july1_2018_positive~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model7 = felm(formula7, data=data, weights=data$weight)
  formula8 = as.formula(str_interp('plan_july1_2018_positive~treatment_main+treatment_main:${var}+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model8 = felm(formula8, data=data, weights=data$weight)
  
  
  
  
  control = data %>% filter(treatment_main==0)
  control_means_2017 = weighted.mean(control$participate_july1_2017, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2017 = weighted.sd(control$participate_july1_2017, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2017 = weighted.mean(data$participate_july1_2017, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2017 = weighted.sd(data$participate_july1_2017, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_means_2018 = weighted.mean(control$participate_july1_2018, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2018 = weighted.sd(control$participate_july1_2018, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2018 = weighted.mean(data$participate_july1_2018, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2018 = weighted.sd(data$participate_july1_2018, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  
  control_means_2017_plan = weighted.mean(control$plan_july1_2017_pos, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2017_plan = weighted.sd(control$plan_july1_2017_pos, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2017_plan = weighted.mean(data$plan_july1_2017_pos, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2017_plan = weighted.sd(data$plan_july1_2017_pos, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_means_2018_plan = weighted.mean(control$plan_july1_2018_positive, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2018_plan = weighted.sd(control$plan_july1_2018_positive, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2018_plan = weighted.mean(data$plan_july1_2018_positive, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2018_plan = weighted.sd(data$plan_july1_2018_positive, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  
  
  control_mean = c(rep(control_means_2017, 2), rep(control_means_2018, 2), NA, rep(control_means_2018_plan, 2))
  control_sd = c(rep(control_sds_2017, 2), rep(control_sds_2018, 2), NA, rep(control_sds_2018_plan, 2))
  all_mean = c(rep(all_means_2017, 2), rep(all_means_2018, 2), NA, rep(all_means_2018_plan, 2))
  all_sd = c(rep(all_sds_2017, 2), rep(all_sds_2018, 2), NA, rep(all_sds_2018_plan, 2))
  
  paren = ifelse(title_weight_tag==' (reweighted sample)', str_interp('(${measure} intensity, reweighted sample)'),
                 str_interp('(${measure} intensity${title_weight_tag})'))
  
  
  empty_model = model1
  empty_model$beta[1:5] = c(NA, NA)
  empty_model$cse[1:5] = c(NA, NA)
  empty_model$N = c(NA)
  
  output_heterogeneity = stargazer(list(model1, model2, model3, model4, empty_model, model7, model8),   # model6, model7 not shown
                                   omit = c( 'Constant', 'predicted', 'tier0$', 'gender'),
                                   covariate.labels = c('Treatment',
                                                        'Treatment $\\times$ 50\\% intensity',
                                                        'Treatment $\\times$ 75\\% intensity'),
                                   omit.stat = c('adj.rsq', 'ser', 'f', 'rsq', 'aic','ll'),
                                   add.lines = list(
                                     c('DV mean (control grp.)', control_mean),
                                     c('DV std. dev. (control grp.)', control_sd),
                                     c('DV mean (all)', all_mean),
                                     c('DV std. dev. (all)', all_sd),
                                     c('Gender controls', 'No', 'Yes', 'No', 'Yes', '', 'No', 'Yes')),
                                   style = "aer", omit.table.layout='n',
                                   star.char = '') %>% 
    star_notes_tex(note = str_interp("Panel~A presents estimated coefficients from regressions of protest turnout (or planned turnout) on the individual treatment indicator. Panel~B presents estimated coefficients from regressions of protest turnout (or planned turnout) on the individual treatment indicator interacted with major$\times$cohort cell treatment intensity bin indicators (and lower-order terms). Results are shown for 2017 protest turnout (columns~1--2), 2018 protest turnout (columns~3--4), and 2018 planned protest turnout (columns~5--6). Columns~1,~3, and~5 include major$\times$cohort cell fixed effects; in addition, columns~2,~4, and~6 include the interaction between individual treatment status and a gender indicator. Standard errors (reported in parentheses) are clustered at the major$\times$cohort cell level. ${note_weight_tag}"))
  
  # Combine Panel A and Panel B
  output_average[11] = str_interp(paste('& \\multicolumn{4}{c}{Participation} & \\multicolumn{1}{c}{\\white{xx}} & \\multicolumn{2}{c}{Plans to participate} \\\\',
                                        '\\cmidrule(rr){2-5} \\cmidrule(rr){7-8} ',
                                        '& 2017 & 2017 & 2018 & 2018 & & 2018 & 2018 \\\\'))
  
  output_average[12] = " \\cmidrule(rr){2-3} \\cmidrule(rr){4-5} \\cmidrule(rr){7-8}"
  output_average[13] = " & (1) & (2) & (3) & (4) & & (5) & (6)\\\\ "
  output = c(output_average[1:8], output_average[11:14], 
             '\\multicolumn{8}{l}{\\textbf{Panel A}: \\textit{Average treatment effect}} \\\\',
             '\\midrule',
             output_average[15:18],
             '\\multicolumn{8}{l}{\\textbf{Panel B}: \\textit{Heterogeneity by cell treatment intensity}} \\\\',
             '\\midrule',
             output_heterogeneity[15:length(output_heterogeneity)])
  
  
  output[which(str_detect(output, 'begin\\{tablenotes\\}'))] = str_replace(output[which(str_detect(output, 'begin\\{tablenotes\\}'))], 'begin\\{tablenotes\\}', 'begin\\{tablenotes\\}[flushleft]')
  
  #Make table small
  output[4] = paste(output[4], '\\small')
  
  writeLines(output, con = str_interp('${out}/participation-${measure}.tex'))
}



# Table D.12: (Table 2 reweighted)
make_outcomes_table = function(data, measure) {
  # Average
  formula1 = as.formula(str_interp('az_polpreferences_post17~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model1 = felm(formula1, data=data, weights=data$weight)
  formula2 = as.formula(str_interp('az_polpreferences_pre18~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model2 = felm(formula2, data=data, weights=data$weight)
  formula3 = as.formula(str_interp('az_polbeliefs_post17~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model3 = felm(formula3, data=data, weights=data$weight)
  formula4 = as.formula(str_interp('az_polbeliefs_pre18~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model4 = felm(formula4, data=data, weights=data$weight)
  formula5 = as.formula(str_interp('az_secbeliefs_post17~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model5 = felm(formula5, data=data, weights=data$weight)
  formula6 = as.formula(str_interp('az_secbeliefs_pre18~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model6 = felm(formula6, data=data, weights=data$weight)
  formula7 = as.formula(str_interp('newfriendship_2018~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model7 = felm(formula7, data=data, weights=data$weight)
  
  output_average = stargazer(list(model7, model1, model2, model3, model4, model5, model6),
                             omit = c('gender','predicted'),
                             covariate.labels = c('Treatment'),
                             title = 'Mechanisms: political beliefs, preferences, beliefs about others, and new friendships (reweighted sample)',
                             label = str_interp('t:outcomes-${measure}'),
                             star.char = '')
  
  # Heterogeneity
  data$approximate_treatment_cell_tier = relevel(data$approximate_treatment_cell_tier, ref=2)
  var = ifelse(measure=='empirical', 'treatment_cell_tier', 'approximate_treatment_cell_tier')
  formula1 = as.formula(str_interp('az_polpreferences_post17~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model1 = felm(formula1, data=data, weights=data$weight)
  formula2 = as.formula(str_interp('az_polpreferences_pre18~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model2 = felm(formula2, data=data, weights=data$weight)
  formula3 = as.formula(str_interp('az_polbeliefs_post17~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model3 = felm(formula3, data=data, weights=data$weight)
  formula4 = as.formula(str_interp('az_polbeliefs_pre18~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model4 = felm(formula4, data=data, weights=data$weight)
  formula5 = as.formula(str_interp('az_secbeliefs_post17~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model5 = felm(formula5, data=data, weights=data$weight)
  formula6 = as.formula(str_interp('az_secbeliefs_pre18~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model6 = felm(formula6, data=data, weights=data$weight)
  formula7 = as.formula(str_interp('newfriendship_2018~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model7 = felm(formula7, data=data, weights=data$weight)
  
  control = data %>% filter(treatment_main==0)
  
  
  
  w = control$weight
  control_means = list(control$newfriendship_2018,
                       control$az_polpreferences_post17, control$az_polpreferences_pre18,
                       control$az_polbeliefs_post17, control$az_polbeliefs_pre18,
                       control$az_secbeliefs_post17, control$az_secbeliefs_pre18) %>% map_chr(formatted_mean_weighted)
  
  control_sds = c(weighted.sd(control$newfriendship_2018, control$weight, na.rm=T),
                  weighted.sd(control$az_polpreferences_post17, control$weight, na.rm=T),
                  weighted.sd(control$az_polpreferences_pre18, control$weight, na.rm=T),
                  weighted.sd(control$az_polbeliefs_post17, control$weight, na.rm=T),
                  weighted.sd(control$az_polbeliefs_pre18, control$weight, na.rm=T),
                  weighted.sd(control$az_secbeliefs_post17, control$weight, na.rm=T),
                  weighted.sd(control$az_secbeliefs_pre18, control$weight, na.rm=T)) %>% round(3) %>% sprintf("%.3f", .)
  
  
  w = data$weight
  all_means = list(data$newfriendship_2018,
                   data$az_polpreferences_post17, data$az_polpreferences_pre18,
                   data$az_polbeliefs_post17, data$az_polbeliefs_pre18,
                   data$az_secbeliefs_post17, data$az_secbeliefs_pre18) %>% map_chr(formatted_mean_weighted)
  

  all_sds = c(weighted.sd(data$newfriendship_2018, data$weight, na.rm=T),
              weighted.sd(data$az_polpreferences_post17, data$weight, na.rm=T),
              weighted.sd(data$az_polpreferences_pre18, data$weight, na.rm=T),
              weighted.sd(data$az_polbeliefs_post17, data$weight, na.rm=T),
              weighted.sd(data$az_polbeliefs_pre18, data$weight, na.rm=T),
              weighted.sd(data$az_secbeliefs_post17, data$weight, na.rm=T),
              weighted.sd(data$az_secbeliefs_pre18, data$weight, na.rm=T)) %>% round(3) %>% sprintf("%.3f", .)
  
  
  paren = ifelse(title_weight_tag==' (reweighted sample)', str_interp('(${measure} intensity, reweighted sample)'),
                 str_interp('(${measure} intensity${title_weight_tag})'))
  
  output_heterogeneity = stargazer(list(model7, model1, model2, model3, model4, model5, model6), 
                                   omit = c( 'Constant', 'predicted', 'tier0$', 'gender'),
                                   covariate.labels = c('Treatment',
                                                        'Treatment $\\times$ 50\\% intensity',
                                                        'Treatment $\\times$ 75\\% intensity'),
                                   omit.stat = c('adj.rsq', 'ser', 'f', 'rsq', 'aic','ll'),
                                   add.lines = list(
                                     c('DV mean (control grp.)', control_means),
                                     c('DV std. dev. (control grp.)', control_sds),
                                     c('DV mean (all)', all_means),
                                     c('DV std. dev. (all)', all_sds)),
                                   style = "aer", omit.table.layout='n',
                                   star.char = '') %>% 
    star_notes_tex(note = str_interp("Panel~A presents estimated coefficients from regressions of new friendships, indices of preferences, political beliefs, and beliefs about others on the individual treatment indicator. Panel~B presents estimated coefficients from regressions of new friendships, indices of preferences, political beliefs, and beliefs about others on the individual treatment indicator interacted with major$\times$cohort cell treatment intensity bin indicators (and lower-order terms). Results are shown for new friendships reported in July 2018 (column~1); for July 2017 preferences, beliefs, and beliefs about others (columns~2,~4,~and~6); and for June 2018 preferences, beliefs, and beliefs about others (columns~3,~5,~and~7).  All regressions include major$\times$cohort cell fixed effects. Standard errors (reported in parentheses) are clustered at the major$\times$cohort cell level. ${note_weight_tag}"))
  
  output_average[11] = str_interp(paste('& \\multicolumn{1}{c}{New friendships} & \\multicolumn{2}{c}{Political preferences} & \\multicolumn{2}{c}{Political beliefs} & \\multicolumn{2}{c}{Beliefs about others} \\\\',
                                        '\\cmidrule(rr){2-2} \\cmidrule(rr){3-4} \\cmidrule(rr){5-6} \\cmidrule(rr){7-8}',
                                        '& 2018 & 2017 & 2018 & 2017 & 2018 & 2017 & 2018 \\\\',
                                        '\\cmidrule(rr){2-2} \\cmidrule(rr){3-3} \\cmidrule(rr){4-4} \\cmidrule(rr){5-5} \\cmidrule(rr){6-6} \\cmidrule(rr){7-7} \\cmidrule(rr){8-8}'))
  
  output = c(output_average[1:8], output_average[11:13], 
             '\\multicolumn{8}{l}{\\textbf{Panel A}: \\textit{Average treatment effect}} \\\\',
             '\\midrule',
             output_average[14:17],
             '\\multicolumn{8}{l}{\\textbf{Panel B}: \\textit{Heterogeneity by cell treatment intensity}} \\\\',
             '\\midrule',
             output_heterogeneity[14:length(output_heterogeneity)])
  
  #Make table small
  output[4] = paste(output[4], '\\small')
  
  
  writeLines(output, con = str_interp('${out}/outcomes-${measure}.tex'))
}


# Table D.7 (Table 1 with controls)
make_participation_table_control = function(data, measure) {
    
  data$approximate_treatment_cell_tier = relevel(data$approximate_treatment_cell_tier, ref=2)
  var = ifelse(measure=='empirical', 'treatment_cell_tier', 'approximate_treatment_cell_tier')
  
  for (panel in list('A', 'B', 'C', 'D', 'E')){
    # covlabels_a = c('Treatment')
    covlabels_b = c('Treatment', 'Treatment $\\times$ 50\\% intensity', 'Treatment $\\times$ 75\\% intensity')
    if (panel == 'A'){
      # xvars_a = 'treatment_main+predicted_protest_participation'
      # xvars_a_gender = 'treatment_main+treatment_main:gender+gender+predicted_protest_participation'
      xvars_b = str_interp('treatment_main+treatment_main:${var}+predicted_protest_participation')
      xvars_b_gender = str_interp('treatment_main+treatment_main:${var}+treatment_main:gender+gender+predicted_protest_participation')
    } else if (panel == 'B'){
      # xvars_a = 'treatment_main+treatment_main:birth_year+predicted_protest_participation'
      # xvars_a_gender = 'treatment_main+treatment_main:birth_year+treatment_main:gender+gender+predicted_protest_participation'
      xvars_b = str_interp('treatment_main+treatment_main:${var}+treatment_main:birth_year+predicted_protest_participation')
      xvars_b_gender = str_interp('treatment_main+treatment_main:${var}+treatment_main:birth_year+treatment_main:gender+gender+predicted_protest_participation')
     } else if (panel == 'C'){
      # xvars_a = 'treatment_main+treatment_main:hs_language_english+predicted_protest_participation'
      # xvars_a_gender = 'treatment_main+treatment_main:hs_language_english+treatment_main:gender+gender+predicted_protest_participation'
      xvars_b = str_interp('treatment_main+treatment_main:${var}+treatment_main:hs_language_english+predicted_protest_participation')
      xvars_b_gender = str_interp('treatment_main+treatment_main:${var}+treatment_main:hs_language_english+treatment_main:gender+gender+predicted_protest_participation')
    } else if (panel == 'D'){
      # xvars_a = 'treatment_main+treatment_main:expectedincome_age40+predicted_protest_participation'
      # xvars_a_gender = 'treatment_main+treatment_main:expectedincome_age40+treatment_main:gender+gender+predicted_protest_participation'
      xvars_b = str_interp('treatment_main+treatment_main:${var}+treatment_main:expectedincome_age40+predicted_protest_participation')
      xvars_b_gender = str_interp('treatment_main+treatment_main:${var}+treatment_main:expectedincome_age40+treatment_main:gender+gender+predicted_protest_participation')
    } else if (panel == 'E'){
      # xvars_a = 'treatment_main+treatment_main:predicted_protest_participation+predicted_protest_participation'
      # xvars_a_gender = 'treatment_main+treatment_main:predicted_protest_participation+treatment_main:gender+gender+predicted_protest_participation'
      xvars_b = str_interp('treatment_main+treatment_main:${var}+treatment_main:predicted_protest_participation+predicted_protest_participation')
      xvars_b_gender = str_interp('treatment_main+treatment_main:${var}+treatment_main:predicted_protest_participation+treatment_main:gender+gender+predicted_protest_participation')
    }  

  
    
    # Panel X (b): Heterogeneity
    formula1 = as.formula(str_interp('participate_july1_2017~${xvars_b}|treatment_cell|0|treatment_cell'))
    model1 = felm(formula1, data=data, weights=data$weight)
    formula2 = as.formula(str_interp('participate_july1_2017~${xvars_b_gender}|treatment_cell|0|treatment_cell'))
    model2 = felm(formula2, data=data, weights=data$weight)
    formula3 = as.formula(str_interp('participate_july1_2018~${xvars_b}|treatment_cell|0|treatment_cell'))
    model3 = felm(formula3, data=data, weights=data$weight)
    formula4 = as.formula(str_interp('participate_july1_2018~${xvars_b_gender}|treatment_cell|0|treatment_cell'))
    model4 = felm(formula4, data=data, weights=data$weight)
    
    formula5 = as.formula(str_interp('plan_july1_2017_pos~${xvars_b}|treatment_cell|0|treatment_cell'))
    model5 = felm(formula5, data=data, weights=data$weight)
    formula6 = as.formula(str_interp('plan_july1_2017_pos~${xvars_b_gender}|treatment_cell|0|treatment_cell'))
    model6 = felm(formula6, data=data, weights=data$weight)
    formula7 = as.formula(str_interp('plan_july1_2018_positive~${xvars_b}|treatment_cell|0|treatment_cell'))
    model7 = felm(formula7, data=data, weights=data$weight)
    formula8 = as.formula(str_interp('plan_july1_2018_positive~${xvars_b_gender}|treatment_cell|0|treatment_cell'))
    model8 = felm(formula8, data=data, weights=data$weight)
    
    if (panel=='A'){
      empty_model = model1
      empty_model$beta[1:5] = c(NA, NA, NA, NA, NA)
      empty_model$cse[1:5] = c(NA, NA, NA, NA, NA)
      empty_model$N = c(NA)
      
      
      #p-value from randomization inference
      data$treatment75 = as.numeric(data$approximate_treatment_cell_tier==0.75 & data$treatment==1)
      data$treatment50 = as.numeric(data$approximate_treatment_cell_tier==0.5 & data$treatment==1)
      
      x_vars_ri = 'treatment_main+treatment50+treatment75+predicted_protest_participation+treatment_cell'
      x_vars_ri_gender = 'treatment_main+treatment50+treatment75+gender+gender:treatment_main+predicted_protest_participation+treatment_cell'
      
      formula1 = as.formula(str_interp('participate_july1_2017~${x_vars_ri}'))
      formula2 = as.formula(str_interp('participate_july1_2017~${x_vars_ri_gender}'))
      formula3 = as.formula(str_interp('participate_july1_2018~${x_vars_ri}'))
      formula4 = as.formula(str_interp('participate_july1_2018~${x_vars_ri_gender}'))
      formula5 = as.formula(str_interp('plan_july1_2017_pos~${x_vars_ri}'))
      formula6 = as.formula(str_interp('plan_july1_2017_pos~${x_vars_ri_gender}'))
      formula7 = as.formula(str_interp('plan_july1_2018_positive~${x_vars_ri}'))
      formula8 = as.formula(str_interp('plan_july1_2018_positive~${x_vars_ri_gender}'))

      
      perms1 = c(get_randomized_inference_p_value(formula1, 'treatment_main', data),
                 get_randomized_inference_p_value(formula2, 'treatment_main', data),
                 get_randomized_inference_p_value(formula3, 'treatment_main', data),
                 get_randomized_inference_p_value(formula4, 'treatment_main', data),
                 #get_randomized_inference_p_value(formula5, 'treatment_main', data),
                 #get_randomized_inference_p_value(formula6, 'treatment_main', data),
                 NA,
                 get_randomized_inference_p_value(formula7, 'treatment_main', data),
                 get_randomized_inference_p_value(formula8, 'treatment_main', data))
      perms2 = c(get_randomized_inference_p_value(formula1, 'treatment50', data),
                 get_randomized_inference_p_value(formula2, 'treatment50', data),
                 get_randomized_inference_p_value(formula3, 'treatment50', data),
                 get_randomized_inference_p_value(formula4, 'treatment50', data),
                 #get_randomized_inference_p_value(formula5, 'treatment50', data),
                 #get_randomized_inference_p_value(formula6, 'treatment50', data),
                 NA,
                 get_randomized_inference_p_value(formula7, 'treatment50', data),
                 get_randomized_inference_p_value(formula8, 'treatment50', data))
      perms3 = c(get_randomized_inference_p_value(formula1, 'treatment75', data),
                 get_randomized_inference_p_value(formula2, 'treatment75', data),
                 get_randomized_inference_p_value(formula3, 'treatment75', data),
                 get_randomized_inference_p_value(formula4, 'treatment75', data),
                 #get_randomized_inference_p_value(formula5, 'treatment75', data),
                 #get_randomized_inference_p_value(formula6, 'treatment75', data),
                 NA,
                 get_randomized_inference_p_value(formula7, 'treatment75', data),
                 get_randomized_inference_p_value(formula8, 'treatment75', data))
      
    } else {
      empty_model = model1
      empty_model$beta[1:6] = c(NA, NA, NA, NA, NA, NA)
      empty_model$cse[1:6] = c(NA, NA, NA, NA, NA, NA)
      empty_model$N = c(NA)
    }
      
    
    if (panel=='A'){
      output_average = stargazer(list(model1, model2, model3, model4, empty_model, model7, model8),   # model5, model6 not shown
                                 omit = c('Constant', 'gender', 'tier0$', 'predicted_protest_participation'),
                                 covariate.labels = covlabels_b,
                                 add.lines = list(c('$p$-value (permutation test)', perms1),
                                                  c('$p$-value (permutation test)', perms2),
                                                  c('$p$-value (permutation test)', perms3)),
                                 title = 'Effects on participation',
                                 label = str_interp('t:participation-${measure}'),
                                 star.char = '')
      coefs_b = c(output_average[15:16], output_average[25],
                  output_average[17:19], output_average[26],
                  output_average[20:22], output_average[27], output_average[23:24])
      

    } else if (panel=='E'){
      output_average = stargazer(list(model1, model2, model3, model4, empty_model, model7, model8),   # model5, model6 not shown
                                 omit = c('Constant', 'gender', 'tier0$', 'predicted'),
                                 covariate.labels = covlabels_b,
                                 title = 'Effects on participation',
                                 label = str_interp('t:participation-${measure}'),
                                 star.char = '')
      coefs_b = c(output_average[15:23], output_average[24])
      
    } else {
      output_average = stargazer(list(model1, model2, model3, model4, empty_model, model7, model8),   # model5, model6 not shown
                                 omit = c('Constant', 'gender', 'tier0$', 'predicted_protest_participation'),
                                 covariate.labels = covlabels_b,
                                 title = 'Effects on participation',
                                 label = str_interp('t:participation-${measure}'),
                                 star.char = '')
      
      coefs_b = c(output_average[15:23], output_average[27])
    }  
    
    
    if (panel=='B'){
      coefs_b[1] = "\\\\[-2.1ex] Treatment & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} \\\\ "
      coefs_b[2] = "  & & & & & & &  \\\\ "
    }
    
    # Combine both parts of panel: (a) and (b)
    if (panel == 'A'){
      panelA = c('\\multicolumn{8}{l}{\\textbf{Panel A}: \\textit{No control -- replication of Table 1}} \\\\',
                 '\\midrule',
                 coefs_b)
    } else if (panel == 'B'){
      panelB = c('\\multicolumn{8}{l}{\\textbf{Panel B}: \\textit{In addition control for birth year}} \\\\',
                 '\\midrule',
                 coefs_b)
    } else if (panel == 'C'){
      panelC = c('\\multicolumn{8}{l}{\\textbf{Panel C}: \\textit{In addition control for English-language High School}} \\\\',
                  '\\midrule',
                 coefs_b)
    } else if (panel == 'D'){
      panelD = c('\\multicolumn{8}{l}{\\textbf{Panel D}: \\textit{In addition control for expected income at age 40}} \\\\',
                 '\\midrule',
                 coefs_b)
    } else if (panel == 'E'){
      panelE = c('\\multicolumn{8}{l}{\\textbf{Panel E}: \\textit{In addition control for predicted protest propensity}} \\\\',
                 '\\midrule',
                 coefs_b)
    }  
  }
  
  
  # Means etc.
  control = data %>% filter(treatment_main==0)
  control_means_2017 = weighted.mean(control$participate_july1_2017, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2017 = weighted.sd(control$participate_july1_2017, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2017 = weighted.mean(data$participate_july1_2017, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2017 = weighted.sd(data$participate_july1_2017, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_means_2018 = weighted.mean(control$participate_july1_2018, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2018 = weighted.sd(control$participate_july1_2018, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2018 = weighted.mean(data$participate_july1_2018, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2018 = weighted.sd(data$participate_july1_2018, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  
  control_means_2017_plan = weighted.mean(control$plan_july1_2017_pos, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2017_plan = weighted.sd(control$plan_july1_2017_pos, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2017_plan = weighted.mean(data$plan_july1_2017_pos, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2017_plan = weighted.sd(data$plan_july1_2017_pos, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_means_2018_plan = weighted.mean(control$plan_july1_2018_positive, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2018_plan = weighted.sd(control$plan_july1_2018_positive, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2018_plan = weighted.mean(data$plan_july1_2018_positive, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2018_plan = weighted.sd(data$plan_july1_2018_positive, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  
  
  control_mean = c(rep(control_means_2017, 2), rep(control_means_2018, 2), NA, rep(control_means_2018_plan, 2))
  control_sd = c(rep(control_sds_2017, 2), rep(control_sds_2018, 2), NA, rep(control_sds_2018_plan, 2))
  all_mean = c(rep(all_means_2017, 2), rep(all_means_2018, 2), NA, rep(all_means_2018_plan, 2))
  all_sd = c(rep(all_sds_2017, 2), rep(all_sds_2018, 2), NA, rep(all_sds_2018_plan, 2))

  paren = ifelse(title_weight_tag==' (reweighted sample)', str_interp('(${measure} intensity, reweighted sample)'),
                 str_interp('(${measure} intensity${title_weight_tag})'))
  
  output_means = stargazer(list(model1, model2, model3, model4, empty_model, model7, model8),  #model5, model6
                                   omit = c( 'Constant', 'predicted', 'tier0$', 'gender'),
                                   omit.stat = c('adj.rsq', 'ser', 'f', 'rsq', 'aic','ll'),
                                   add.lines = list(
                                     c('DV mean (control grp.)', control_mean),
                                     c('DV std. dev. (control grp.)', control_sd),
                                     c('DV mean (all)', all_mean),
                                     c('DV std. dev. (all)', all_sd),
                                     c('Gender controls', 'No', 'Yes', 'No', 'Yes', '', 'No', 'Yes')),
                                   style = "aer", omit.table.layout='n',
                                   star.char = '') %>% 
    star_notes_tex(note = str_interp("Placeholder. ${note_weight_tag}"))
  
  
  
  ###Combine all panels
  #Table beginning
  output_means[11] = str_interp(paste('& \\multicolumn{4}{c}{Participation} & \\multicolumn{1}{c}{\\white{xx}} & \\multicolumn{2}{c}{Plans to participate} \\\\',
                                        '\\cmidrule(rr){2-5} \\cmidrule(rr){7-8} ',
                                        '& 2017 & 2017 & 2018 & 2018 & & 2018 & 2018 \\\\'))
  
  output_means[12] = " \\cmidrule(rr){2-3} \\cmidrule(rr){4-5} \\cmidrule(rr){7-8}"
  output_means[13] = " & (1) & (2) & (3) & (4) & & (5) & (6)\\\\ "
  table_beginning = c(output_means[1:8], output_means[11:14])
  # Table end
  table_end = output_means[25:length(output_means)]
  
  # Combine
  output = c(table_beginning,
             panelA, panelB, panelC, panelD, panelE,
             table_end)
  
  
  
  output[which(str_detect(output, 'begin\\{tablenotes\\}'))] = str_replace(output[which(str_detect(output, 'begin\\{tablenotes\\}'))], 'begin\\{tablenotes\\}', 'begin\\{tablenotes\\}[flushleft]')
  
  #Make table small
  output[4] = paste(output[4], '\\small')
  
  # MAke table longtable
  output_long = c(output[1:3], '\\small', "\\begin{longtable}{@{\\hspace{5pt}}l@{\\hspace{5pt}}cccccccc} ", #output[5:6],
                  output[8:63], '\\pagebreak', output[64:(length(output)-3)], output[length(output)-1], '\\end{longtable} ')
  
  writeLines(output_long, con = str_interp('${out}/participation-${measure}-controls_for_unbalanced.tex'))
}




# Table D.8 (Table 2 with controls)
make_outcomes_table_control = function(data, measure) {
  
  data$approximate_treatment_cell_tier = relevel(data$approximate_treatment_cell_tier, ref=2)
  var = ifelse(measure=='empirical', 'treatment_cell_tier', 'approximate_treatment_cell_tier')
  
  for (panel in list('A', 'B', 'C', 'D', 'E')){
    # covlabels_a = c('Treatment')
    covlabels_b = c('Treatment', 'Treatment $\\times$ 50\\% intensity', 'Treatment $\\times$ 75\\% intensity')
    if (panel == 'A'){
      # xvars_a = 'treatment_main+predicted_protest_participation'
      xvars_b = str_interp('treatment_main+treatment_main:${var}+predicted_protest_participation')
    } else if (panel == 'B'){
      # xvars_a = 'treatment_main+treatment_main:birth_year+predicted_protest_participation'
      xvars_b = str_interp('treatment_main+treatment_main:${var}+treatment_main:birth_year+predicted_protest_participation')
    } else if (panel == 'C'){
      # xvars_a = 'treatment_main+treatment_main:hs_language_english+predicted_protest_participation'
      xvars_b = str_interp('treatment_main+treatment_main:${var}+treatment_main:hs_language_english+predicted_protest_participation')
    } else if (panel == 'D'){
      # xvars_a = 'treatment_main+treatment_main:expectedincome_age40+predicted_protest_participation'
      xvars_b = str_interp('treatment_main+treatment_main:${var}+treatment_main:expectedincome_age40+predicted_protest_participation')
    } else if (panel == 'E'){
      # xvars_a = 'treatment_main+treatment_main:predicted_protest_participation+predicted_protest_participation'
      xvars_b = str_interp('treatment_main+treatment_main:${var}+treatment_main:predicted_protest_participation+predicted_protest_participation')
    }  
    
    
  
    
    
    # Panel X (b): Heterogeneity
    formula1 = as.formula(str_interp('az_polpreferences_post17~${xvars_b}|treatment_cell|0|treatment_cell'))
    model1 = felm(formula1, data=data, weights=data$weight)
    formula2 = as.formula(str_interp('az_polpreferences_pre18~${xvars_b}|treatment_cell|0|treatment_cell'))
    model2 = felm(formula2, data=data, weights=data$weight)
    formula3 = as.formula(str_interp('az_polbeliefs_post17~${xvars_b}|treatment_cell|0|treatment_cell'))
    model3 = felm(formula3, data=data, weights=data$weight)
    formula4 = as.formula(str_interp('az_polbeliefs_pre18~${xvars_b}|treatment_cell|0|treatment_cell'))
    model4 = felm(formula4, data=data, weights=data$weight)
    formula5 = as.formula(str_interp('az_secbeliefs_post17~${xvars_b}|treatment_cell|0|treatment_cell'))
    model5 = felm(formula5, data=data, weights=data$weight)
    formula6 = as.formula(str_interp('az_secbeliefs_pre18~${xvars_b}|treatment_cell|0|treatment_cell'))
    model6 = felm(formula6, data=data, weights=data$weight)
    formula7 = as.formula(str_interp('newfriendship_2018~${xvars_b}|treatment_cell|0|treatment_cell'))
    model7 = felm(formula7, data=data, weights=data$weight)
    
    
    
    if (panel=='A'){

      #p-value from randomization inference
      data$treatment75 = as.numeric(data$approximate_treatment_cell_tier==0.75 & data$treatment==1)
      data$treatment50 = as.numeric(data$approximate_treatment_cell_tier==0.5 & data$treatment==1)
      
      x_vars_ri = 'treatment_main+treatment50+treatment75+predicted_protest_participation+treatment_cell'

      formula1 = as.formula(str_interp('az_polpreferences_post17~${x_vars_ri}'))
      formula2 = as.formula(str_interp('az_polpreferences_pre18~${x_vars_ri}'))
      formula3 = as.formula(str_interp('az_polbeliefs_post17~${x_vars_ri}'))
      formula4 = as.formula(str_interp('az_polbeliefs_pre18~${x_vars_ri}'))
      formula5 = as.formula(str_interp('az_secbeliefs_post17~${x_vars_ri}'))
      formula6 = as.formula(str_interp('az_secbeliefs_pre18~${x_vars_ri}'))
      formula7 = as.formula(str_interp('newfriendship_2018~${x_vars_ri}'))

      
      perms1 = c(get_randomized_inference_p_value(formula7, 'treatment_main', data),
                 get_randomized_inference_p_value(formula1, 'treatment_main', data),
                 get_randomized_inference_p_value(formula2, 'treatment_main', data),
                 get_randomized_inference_p_value(formula3, 'treatment_main', data),
                 get_randomized_inference_p_value(formula4, 'treatment_main', data),
                 get_randomized_inference_p_value(formula5, 'treatment_main', data),
                 get_randomized_inference_p_value(formula6, 'treatment_main', data))
      perms2 = c(get_randomized_inference_p_value(formula7, 'treatment50', data),
                 get_randomized_inference_p_value(formula1, 'treatment50', data),
                 get_randomized_inference_p_value(formula2, 'treatment50', data),
                 get_randomized_inference_p_value(formula3, 'treatment50', data),
                 get_randomized_inference_p_value(formula4, 'treatment50', data),
                 get_randomized_inference_p_value(formula5, 'treatment50', data),
                 get_randomized_inference_p_value(formula6, 'treatment50', data))
      perms3 = c(get_randomized_inference_p_value(formula7, 'treatment75', data),
                 get_randomized_inference_p_value(formula1, 'treatment75', data),
                 get_randomized_inference_p_value(formula2, 'treatment75', data),
                 get_randomized_inference_p_value(formula3, 'treatment75', data),
                 get_randomized_inference_p_value(formula4, 'treatment75', data),
                 get_randomized_inference_p_value(formula5, 'treatment75', data),
                 get_randomized_inference_p_value(formula6, 'treatment75', data))
      
   
      
      output_average = stargazer(list(model7, model1, model2, model3, model4, model5, model6),
                                 omit = c( 'Constant', 'predicted', 'tier0$', 'gender'),
                                 covariate.labels = covlabels_b,
                                 add.lines = list(c('$p$-value (permutation test)', perms1),
                                                  c('$p$-value (permutation test)', perms2),
                                                  c('$p$-value (permutation test)', perms3)),
                                 omit.stat = c('adj.rsq', 'ser', 'f', 'rsq', 'aic','ll'),
                                 style = "aer", omit.table.layout='n',
                                 star.char = '')
      coefs_b = c(output_average[14:15], output_average[24],
                  output_average[16:18], output_average[25],
                  output_average[19:21], output_average[26], output_average[22:23])
      
      

    } else if (panel=='E'){
      output_average = stargazer(list(model7, model1, model2, model3, model4, model5, model6), 
                                 omit = c( 'Constant', 'predicted', 'tier0$', 'gender'),
                                 covariate.labels = covlabels_b,
                                 omit.stat = c('adj.rsq', 'ser', 'f', 'rsq', 'aic','ll'),
                                 style = "aer", omit.table.layout='n',
                                 star.char = '')
      coefs_b = c(output_average[14:22], output_average[23])
      
    } else {
       output_average = stargazer(list(model7, model1, model2, model3, model4, model5, model6), 
                                       omit = c( 'Constant', 'predicted', 'tier0$', 'gender'),
                                       covariate.labels = covlabels_b,
                                       omit.stat = c('adj.rsq', 'ser', 'f', 'rsq', 'aic','ll'),
                                       style = "aer", omit.table.layout='n',
                                       star.char = '')
         coefs_b = c(output_average[14:22], output_average[26])
    }
    
    if (panel=='B'){
      coefs_b[1] = "\\\\[-2.1ex] Treatment & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} & \\ensuremath{\\cdot} \\\\ "
      coefs_b[2] = "  & & & & & & &  \\\\ "
    }
           
   
    # Combine both parts of panel: (a) and (b)
    if (panel == 'A'){
      panelA = c('\\multicolumn{8}{l}{\\textbf{Panel A}: \\textit{No control -- replication of Table 3}} \\\\',
                  '\\midrule',
                 coefs_b)
    } else if (panel == 'B'){
      panelB = c('\\multicolumn{8}{l}{\\textbf{Panel B}: \\textit{In addition control for birth year}} \\\\',
                  '\\midrule',
                 coefs_b)
    } else if (panel == 'C'){
      panelC = c('\\multicolumn{8}{l}{\\textbf{Panel C}: \\textit{In addition control for English-language High School}} \\\\',
                 '\\midrule',
                 coefs_b)
    } else if (panel == 'D'){
      panelD = c('\\multicolumn{8}{l}{\\textbf{Panel D}: \\textit{In addition control for expected income at age 40}} \\\\',
                   '\\midrule',
                 coefs_b)
    } else if (panel == 'E'){
      panelE = c('\\multicolumn{8}{l}{\\textbf{Panel E}: \\textit{In addition control for predicted protest propensity}} \\\\',
                  '\\midrule',
                 coefs_b)
    }  
  }
  
  
  # Means etc.
  control = data %>% filter(treatment_main==0)
  
  w = control$weight
  control_means = list(control$newfriendship_2018,
                       control$az_polpreferences_post17, control$az_polpreferences_pre18,
                       control$az_polbeliefs_post17, control$az_polbeliefs_pre18,
                       control$az_secbeliefs_post17, control$az_secbeliefs_pre18) %>% map_chr(formatted_mean_weighted)
  
  control_sds = c(weighted.sd(control$newfriendship_2018, control$weight, na.rm=T),
                  weighted.sd(control$az_polpreferences_post17, control$weight, na.rm=T),
                  weighted.sd(control$az_polpreferences_pre18, control$weight, na.rm=T),
                  weighted.sd(control$az_polbeliefs_post17, control$weight, na.rm=T),
                  weighted.sd(control$az_polbeliefs_pre18, control$weight, na.rm=T),
                  weighted.sd(control$az_secbeliefs_post17, control$weight, na.rm=T),
                  weighted.sd(control$az_secbeliefs_pre18, control$weight, na.rm=T)) %>% round(3) %>% sprintf("%.3f", .)
  
  w = data$weight
  all_means = list(data$newfriendship_2018,
                   data$az_polpreferences_post17, data$az_polpreferences_pre18,
                   data$az_polbeliefs_post17, data$az_polbeliefs_pre18,
                   data$az_secbeliefs_post17, data$az_secbeliefs_pre18) %>% map_chr(formatted_mean_weighted)
  
  all_sds = c(weighted.sd(data$newfriendship_2018, data$weight, na.rm=T),
              weighted.sd(data$az_polpreferences_post17, data$weight, na.rm=T),
              weighted.sd(data$az_polpreferences_pre18, data$weight, na.rm=T),
              weighted.sd(data$az_polbeliefs_post17, data$weight, na.rm=T),
              weighted.sd(data$az_polbeliefs_pre18, data$weight, na.rm=T),
              weighted.sd(data$az_secbeliefs_post17, data$weight, na.rm=T),
              weighted.sd(data$az_secbeliefs_pre18, data$weight, na.rm=T)) %>% round(3) %>% sprintf("%.3f", .)
  
  
  paren = ifelse(title_weight_tag==' (reweighted sample)', str_interp('(${measure} intensity, reweighted sample)'),
                 str_interp('(${measure} intensity${title_weight_tag})'))
  
  
  output_means = stargazer(list(model1, model2, model3, model4, model5, model6, model7), 
                                   omit = c( 'Constant', 'predicted', 'tier0$', 'gender'),
                                   covariate.labels = c('Treatment',
                                                        'Treatment $\\times$ 50\\% intensity',
                                                        'Treatment $\\times$ 75\\% intensity'),
                                   omit.stat = c('adj.rsq', 'ser', 'f', 'rsq', 'aic','ll'),
                                   add.lines = list(
                                     c('DV mean (control grp.)', control_means),
                                     c('DV std. dev. (control grp.)', control_sds),
                                     c('DV mean (all)', all_means),
                                     c('DV std. dev. (all)', all_sds)),
                                   style = "aer", omit.table.layout='n',
                                   star.char = '') %>% 
    star_notes_tex(note = str_interp("Placeholder. ${note_weight_tag}"))
  
  
  ###Combine all panels
  #Table beginning
  #output_means[11] = str_interp('\\\\ & \\multicolumn{2}{c}{2017 participation} & \\multicolumn{2}{c}{2018 participation} & \\multicolumn{2}{c}{2017 plan}  & \\multicolumn{2}{c}{2018 plan} \\\\')
  output_means[11] = str_interp(paste('& \\multicolumn{1}{c}{New friendships} & \\multicolumn{2}{c}{Political preferences} & \\multicolumn{2}{c}{Political beliefs} & \\multicolumn{2}{c}{Beliefs about others} \\\\',
                                        '\\cmidrule(rr){2-2} \\cmidrule(rr){3-4} \\cmidrule(rr){5-6} \\cmidrule(rr){7-8}',
                                        '& 2018 & 2017 & 2018 & 2017 & 2018 & 2017 & 2018 \\\\',
                                        '\\cmidrule(rr){2-2} \\cmidrule(rr){3-3} \\cmidrule(rr){4-4} \\cmidrule(rr){5-5} \\cmidrule(rr){6-6} \\cmidrule(rr){7-7} \\cmidrule(rr){8-8}'))
  
  table_beginning = c(output_means[1:8], output_means[11:13])
  # Table end
  table_end = output_means[24:length(output_means)]
  
  # Combine
  output = c(table_beginning,
             panelA, panelB, panelC, panelD, panelE,
             table_end)
  
  
  
  output[which(str_detect(output, 'begin\\{tablenotes\\}'))] = str_replace(output[which(str_detect(output, 'begin\\{tablenotes\\}'))], 'begin\\{tablenotes\\}', 'begin\\{tablenotes\\}[flushleft]')
  
  #Make table small
  output[4] = paste(output[4], '\\small')
  
  # MAke table longtable
  output_long = c(output[1:3], '\\small', "\\begin{longtable}{@{\\hspace{5pt}}l@{\\hspace{5pt}}cccccccc} ", #output[5:6],
                  output[8:62], '\\pagebreak', output[63:(length(output)-3)], output[length(output)-1], '\\end{longtable} ')
  

  writeLines(output_long, con = str_interp('${out}/outcomes-${measure}-controls_for_unbalanced.tex'))
}





# =================================  RUN ==================================# 

# Run
run_models = function(data) {
  make_participation_table(data, 'target')  # Table D.11
  make_outcomes_table(data, 'target') # Table D.12
  make_interactions_linear(data, measure='empirical') # Figure D.3

  if (out!='reweight' & out!='reweight-merge') {
    make_balance(data, type = 'any_past_protests-tr') # Table D.2
    make_balance(data, type = 'balance3') # Table D.5
    make_balance(data, type = 'attrition') # Table D.1
    make_cell_balance(data) # Table D.6 
  }
}



main = function() {
  merge_cells <<- F
  data = prepare_data()
  out <<- 'minimal'
  title_weight_tag <<- ''
  note_weight_tag <<- ''
  label_weight_tag <<- ''
  dir.create(out)
  dir.create('data/working')
  constrained_sample = data[!is.na(data$az_polbeliefs_post18) & !is.na(data$az_polbeliefs_pre18) & !is.na(data$plan_july1_2018_positive),]
  write_dta(constrained_sample, 'data/working/minimal.dta')
  make_participation_bar_graphs(constrained_sample)  # Figure D.2
  make_participation_table_control(constrained_sample, 'target')  # Table D.7
  make_outcomes_table_control(constrained_sample, 'target')  # Table D.8
  
  run_models(constrained_sample)
  out <<- 'reweight'
  title_weight_tag <<- ' (reweighted sample)'
  note_weight_tag <<- ' Observations re-weighted to match the sample of individuals who completed at least one wave of the study on observables.'
  label_weight_tag <<- '-reweight'
  dir.create(out)
  reweight_sample = constrained_sample
  reweight_sample$weight = entropy_weighting(reweight_sample)
  run_models(reweight_sample)
  
}

main()




