********************************************************************************
*	HK Nudge Experiment - Naturally Occurring Persistence Rate
********************************************************************************

********************************************************************************

* 	Stata settings
	clear all
	set more off, perm
	capture log close

				
********************************************************************************	
*	Program: Anderson z-score
********************************************************************************					

	cap program drop andersonz 
	program andersonz
	syntax varlist [if] [in], GENerate(name)

	* 	Convert to effect sizes
		local varliste ""
		foreach X of varlist `varlist' {
			qui sum `X' `if'
			gen `X'e = `X'/r(sd) `if'
			local csd = r(sd)
			qui sum `X'
			replace `X'e = `X'e - r(mean)/`csd'
			local varliste "`varliste' `X'e" 
			}
	
	*   Generate GLS weighting matrix
		matrix accum R = `varliste', nocons dev
		matrix R = R/r(N)
		matrix R = syminv(R)
		local counter1 = 1
		matrix J = J(colsof(R),1,1)
		while `counter1' <= colsof(R) {
			matrix T = R[`counter1',1..colsof(R)]
			matrix A = T*J
			local weight`counter1'f = A[1,1]
			local counter1 = `counter1' + 1
			}
	
	*   Generate total number of variables per obs
	*   As opposed to Anderson's code, do not replace missing with zeros
		cap drop sample
		gen sample = 0
		local counter1 = 1
		foreach X of varlist `varlist' {
			replace sample = sample + `weight`counter1'f' if `X'~=.
	*		replace `X'e = 0 if `X' ==.
			local counter1 = `counter1' + 1
			}
	
	*   Apply weights to outcomes
		quietly gen `generate' = 0 `if'
		
		local counter1 = 1
		foreach X of varlist `varlist' {
			replace `generate' = `X'e * (`weight`counter1'f') + `generate' `if'
			local counter1 = `counter1' + 1
			}
			
		replace `generate' = `generate' / sample `if'
		cap drop sample
		cap drop `varliste'
		
	* 	Re-standardize aggregate z-score
		egen z_`generate' = std(`generate')
		drop `generate'
		rename z_`generate' `generate'
	
	end

********************************************************************************
*	Data Preparation
********************************************************************************

*	Load the data
	use data/raw/deidentified_data_w12345_minimal.dta, clear

	
*	Create additional variables
	
	* HK local: self
	gen hk_local = .
	replace hk_local = 1 	if (birth_place == "HK" | move_hk_age <= 10)
	replace hk_local = 0 	if (birth_place != "HK" & move_hk_age > 10)
	label variable hk_local "Hong Kong local"
	
	* Student indicator
	gen student = _n	

	
*	Anderson z-scores (separately by waves)
	
	/* NOTE: 	For the underlying variables of the z-scores (monthly_hh_income_total, realest_totalowned, projected_income_median, and expectedincome_age40),
				it is often the case that information is only available for one year. I replace missing values by forward and backward inter-/extrapolation
				to increase the number of observations in the regression samples.
				
				After the interpolation, I create the z-scores separately by wave, i.e. for each wave the z-score has mean 1 and standard deviation 0.
				
				Alternatively, I computed the z-score after introducing the panel format, i.e. the standardization and re-weighting is done across waves; here,
				the mean and standard deviation are not necessarily 1 or 0 for a given wave. In the end, the differeneces are minimal, also with respect to the
				regression results (after selecting the subset of HK locals). The results shown in the tables are based on the first version of z-scores.
	*/

	* Interpolation for underlying variables of the Anderson z-scores
	preserve
	
		foreach var in monthly_income_hh_total_ realest_totalowned_ projected_income_median_ expectedincome_age40_ {
			rename `var'w3 `var'2016
			rename `var'w4 `var'2017
			rename `var'w5 `var'2018	
		}
		rename monthly_income_hh_total_w2		monthly_income_hh_total_2015
		rename projected_income_median_w2		projected_income_median_2015
			
		* Create panel dataset
		keep student monthly_income_hh_total_* realest_totalowned_* projected_income_median_* expectedincome_age40_*
		reshape long monthly_income_hh_total_ realest_totalowned_ projected_income_median_ expectedincome_age40_, i(student) j(year)
		xtset student year
		
		* Interpolation
		foreach var in monthly_income_hh_total_ realest_totalowned_ projected_income_median_ expectedincome_age40_ {
			
			* Forward (first step)
			bys student: replace `var' = L.`var' if `var' >= .
		
			* Backward (second step)
			gsort student -year
			by student: replace `var' = `var'[_n-1] if `var' >= .
			sort student year
		}
		
		* Reformat and save
		reshape wide monthly_income_hh_total_ realest_totalowned_ projected_income_median_ expectedincome_age40_, i(student) j(year)
		save "data/working/interpolated_values.dta", replace
	
	restore

	
	* Merge with full data
	merge 1:1 student using "data/working/interpolated_values.dta", update replace
	erase "data/working/interpolated_values.dta"
	
	* Create Anderson z-scores (separately by wave)
	forvalues t = 2015/2018 {

		local var_demogra_hhecon_`t' 			`"monthly_income_hh_total_`t' realest_totalowned_`t' father_educ_hsabove mother_educ_hsabove"'
		local var_demogra_ownecon_`t' 			`"projected_income_median_`t' expectedincome_age40_`t'"'

		andersonz `var_demogra_hhecon_`t'', gen(az_demogra_hhecon_`t')
		label variable az_demogra_hhecon_`t' "Anderson z-score - F.1: HH economic & social status"

		andersonz `var_demogra_ownecon_`t'', gen(az_demogra_ownecon_`t')
		label variable az_demogra_ownecon_`t' "Anderson z-score - F.2: Own projected economic status"
		
	}

	andersonz hs_language_english hk_generation, gen(az_demogra_childenv)
	label variable az_demogra_childenv "Anderson z-score - G.3: HK-oriented childhood env."
	
	

*	Create final dataset
			
	* Set the treatment groups in the 2016 and 2017 experiments to missing
		* When t >= 2016, only among students in the control groups of the 2016 experiment and 2017-18 experiments
		* 2016 experiment: belief_treatment_w3 != 1
		* 2016 demosisto donation experiment: ignore as not directly related to protest participation
		* 2017 experiment: treatment_main_w4 != 1
	replace participate_july1_2016 = . if belief_treatment_w3 == 1
	replace participate_july1_2017 = . if belief_treatment_w3 == 1
	replace participate_july1_2018 = . if belief_treatment_w3 == 1
	replace participate_july1_2017 = . if treatment_main_w4 == 1
	replace participate_july1_2018 = . if treatment_main_w4 == 1
	
	* Create panel dataset
	keep hk_local student participate_july1_* az_demogra_hhecon_* az_demogra_ownecon_* gender birth_year az_demogra_childenv religion_none monthly_income_hh_total_2* realest_totalowned_2* projected_income_median_2* expectedincome_age40_2* hs_language_english hk_generation father_educ_hsabove mother_educ_hsabove
	reshape long participate_july1_ az_demogra_hhecon_ az_demogra_ownecon_ monthly_income_hh_total_ realest_totalowned_ projected_income_median_ expectedincome_age40_, i(student) j(year)
	rename participate_july1_ participate_july1
	rename az_demogra_hhecon_ az_demogra_hhecon
	rename az_demogra_ownecon_ az_demogra_ownecon

	* Create alternative Anderson z-scores (across all waves)
	andersonz monthly_income_hh_total_ realest_totalowned_ father_educ_hsabove mother_educ_hsabove, gen(az_demogra_hhecon_2)
	label variable az_demogra_hhecon_2 "Anderson z-score - F.1: HH economic & social status"

	andersonz projected_income_median_ expectedincome_age40_, gen(az_demogra_ownecon_2)
	label variable az_demogra_ownecon_2 "Anderson z-score - F.2: Own projected economic status"
	
	andersonz hs_language_english hk_generation, gen(az_demogra_childenv_2)
	label variable az_demogra_childenv_2 "Anderson z-score - G.3: HK-oriented childhood env."
		
	* Select HK locals
	keep if hk_local == 1

	* Select variables
	keep student year participate_july1 gender birth_year religion_none az_*
	
	* Declare panel data
	xtset student year

	* Create lags
	gen L1_participate_july1 = L.participate_july1
	gen L2_participate_july1 = L.L1_participate_july1
	gen L3_participate_july1 = L.L2_participate_july1
	gen L4_participate_july1 = L.L3_participate_july1
	
	* Label variables
	label variable gender				"Male"
	label variable religion_none		"Not religious"
	label variable az_demogra_childenv	"HK-oriented childhood env."
	label variable az_demogra_hhecon	"HH economic and social status"
	label variable az_demogra_ownecon	"Own projected economic status"
	
	label variable L1_participate_july1	"Participation in \(t\)-1"
	label variable L2_participate_july1	"Participation in \(t\)-2"
	label variable L3_participate_july1	"Participation in \(t\)-3"
	label variable L4_participate_july1	"Participation in \(t\)-4"
	
	
********************************************************************************
*	Regressions
********************************************************************************
	
*	NOTE: I use the current and past participation (i.e. when regressing participation in t on t-1, the information in t is either taken from the survey in year t (current) or in years t+1, t+2, ... (past participation)
	
	
*	Define set of control variables	
	local controls `"gender birth_year religion_none az_demogra_childenv az_demogra_hhecon az_demogra_ownecon"'
			
*	Separately by year: July 1st participation in year t on participation in t-1
		
	* Summary statistics
	forvalues t = 2014/2018 {
		tab participate_july1 if year == `t'
	}
	
	* Regressions (separately for each t)
	eststo clear
	forvalues t = 2015/2018 {
	
		* Baseline
		eststo: reg participate_july1 L1_participate_july1 if year == `t', r
		
		* With controls
		eststo: reg participate_july1 L1_participate_july1 `controls' if year == `t', r
		*reg participate_july1 L1_participate_july1 gender birth_year religion_none az_demogra_childenv_2 az_demogra_hhecon_2 az_demogra_ownecon_2 if year == `t', r
	
	}
	estadd ysumm: *
	esttab using persistence_natural_1.tex, replace fragment booktabs se ar2 scalar("ymean Mean of Dep. Var." "ysd SD of Dep. Var.") brackets nomtitles nodepvars nocons compress mlabels(none) collabels(none) ///
		cells(b(fmt(%04.3f)) se(par([ ]))) label
	eststo clear
	
